@@ -1,9 +1,9 @@
 """Create plotly figures from pandas Dataframe."""
 
 
-from ladybug_geometry.geometry2d.pointvector import Point2D
 import numpy as np
 import pandas as pd
+import warnings
 
 from math import ceil, floor, cos, radians
 from typing import Union, List, Tuple
@@ -25,13 +25,14 @@ from .utils import Strategy, StrategyParameters
 from ladybug.datacollection import HourlyContinuousCollection, \
     HourlyDiscontinuousCollection, MonthlyCollection, DailyCollection, BaseCollection
 from ladybug.windrose import WindRose
-from ladybug.color import Color
+from ladybug.color import Color, Colorset
 from ladybug_pandas.series import Series
 from ladybug import psychrometrics as psy
 from ladybug.sunpath import Sunpath
 from ladybug.psychchart import PsychrometricChart
 from ladybug.dt import DateTime
 from ladybug_comfort.chart.polygonpmv import PolygonPMV
+from ladybug_geometry.geometry2d.pointvector import Point2D
 
 
 # set white background in all charts
@@ -40,7 +41,7 @@ pio.templates.default = 'plotly_white'
 
 def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousCollection],
              min_range: float = None, max_range: float = None,
-             colorset: ColorSet = ColorSet.original) -> Figure:
+             colors: List[Color] = None, title: str = None, show_title: bool = False) -> Figure:
     """Create a plotly heat map figure from Ladybug Hourly data.
 
     Args:
@@ -50,7 +51,10 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
             will be calculated based on data. Defaults to None.
         max_range: The maximum value for the legend of the heatmap. If not set, value
             will be calculated based on data. Defaults to None.
-        colorset: A ColorSets object. Defaults to Original Ladybug Colorset.
+        colors: A list of Ladybug Color objects. Defaults to None.
+        title: A string to be used as the title of the plot. If not set, the name
+            of the data will be used. Defaults to None.
+        show_title: A boolean to show or hide the title of the chart. Defaults to False.
 
     Returns:
         A plotly figure.
@@ -79,6 +83,9 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
         # Set maximum and minimum according to data
         range_z = [5 * floor(df[var].min() / 5), 5 * ceil(df[var].max() / 5)]
 
+    if not colors:
+        colors = color_set[ColorSet.original.value]
+
     fig = go.Figure(
         data=go.Heatmap(
             y=df["hour"],
@@ -86,7 +93,7 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
             z=df[var],
             zmin=range_z[0],
             zmax=range_z[1],
-            colorscale=[rgb_to_hex(color) for color in color_set[colorset.value]],
+            colorscale=[rgb_to_hex(color) for color in colors],
             customdata=np.stack((df["month_names"], df["day"]), axis=-1),
             hovertemplate=(
                 "<b>"
@@ -103,18 +110,27 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
     fig.update_xaxes(dtick="M1", tickformat="%b", ticklabelmode="period")
     fig.update_yaxes(title_text="Hours of the day")
 
+    # setting the title for the figure
+    if show_title:
+        fig_title = {
+            'text': title if title else var,
+            'y': 1,
+            'x': 0.5,
+            'xanchor': 'center',
+            'yanchor': 'top'
+        }
+    else:
+        if title:
+            raise ValueError(
+                f'Title is set to "{title}" but show_title is set to False.')
+        fig_title = None
+
     fig.update_layout(
         template='plotly_white',
         margin=dict(
             l=20, r=20, t=33, b=20),
         yaxis_nticks=13,
-        title={
-            'text': var,
-            'y': 1,
-            'x': 0.5,
-            'xanchor': 'center',
-            'yanchor': 'top'
-        },
+        title=fig_title,
     )
     fig.update_xaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
     fig.update_yaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
@@ -190,18 +206,26 @@ def _daily_bar(data: DailyCollection, var: str, var_unit: str,
 
 
 def bar_chart(data: Union[List[MonthlyCollection], List[DailyCollection]],
-              chart_title: str = None,
+              min_range: float = None, max_range: float = None,
               colors: List[Color] = None,
+              title: str = None,
+              show_title: bool = False,
               stack: bool = False) -> Figure:
     """Create a plotly bar chart figure from multiple ladybug monthly or daily data.
 
     Args:
         data: A list of ladybug monthly data or a list of ladybug daily data.
-        chart_title: A string to be used as the title of the plot. If not set, the
-            names of data will be used to create a title for the chart. Defaults to None.
+        min_range: Minimum value for the legend. If not set will be calculated
+            from the data. Defaults to None.
+        max_range: Maximum value for the legend. If not set will be calculated
+            from the data. Defaults to None.
         colors: A list of ladybug color objects. The length of this list needs to match
             the length of data argument. If not set, random colors will be used.
             Defaults to None.
+        title: A string to be used as the title of the plot. If not set, the
+            names of data will be used to create a title for the chart. Defaults to None.
+        show_title: A boolean to set whether to show the title of the chart.
+            Defaults to False.
         stack: A boolean to determine whether to stack the data. Defaults to False which
             will show data side by side.
 
@@ -216,6 +240,12 @@ def bar_chart(data: Union[List[MonthlyCollection], List[DailyCollection]],
         assert len(colors) == len(data), 'Length of colors argument needs to match'\
             f' the length of data argument. Instead got {len(colors)} and {len(data)}'
 
+    # set the range of y-axis if provided
+    if min_range == None and max_range == None:
+        range = None
+    elif min_range != None and max_range != None:
+        range = [min_range, max_range]
+
     fig = go.Figure()
     names = []
 
@@ -236,28 +266,36 @@ def bar_chart(data: Union[List[MonthlyCollection], List[DailyCollection]],
             fig.add_trace(bar)
             names.append(var)
 
-    chart_title = chart_title if chart_title else ' - '.join(names)
+    # setting the title for the figure
+    if show_title:
+        fig_title = {
+            'text': title if title else ' - '.join(names),
+            'y': 1,
+            'x': 0.5,
+            'xanchor': 'center',
+            'yanchor': 'top'
+        }
+    else:
+        if title:
+            raise ValueError(
+                f'Title is set to "{title}" but show_title is set to False.')
+        fig_title = None
 
-    fig.update_xaxes(dtick="M1", tickformat="%b", ticklabelmode="period")
     fig.update_layout(
         barmode='relative' if stack else 'group',
         template='plotly_white',
         margin=dict(l=20, r=20, t=33, b=20),
         yaxis_nticks=13,
-        title={
-            'text': chart_title,
-            'y': 1,
-            'x': 0.5,
-            'xanchor': 'center',
-            'yanchor': 'top'
-        },
+        title=fig_title,
         legend={
             'x': 0,
-            'y': 1.2,
+            'y': 1.1,
         }
     )
-    fig.update_xaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
-    fig.update_yaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
+    fig.update_xaxes(dtick="M1", tickformat="%b", ticklabelmode="period",
+                     showline=True, linewidth=1, linecolor="black", mirror=True)
+    fig.update_yaxes(showline=True, linewidth=1,
+                     linecolor="black", mirror=True, range=range)
 
     return fig
 
@@ -572,15 +610,13 @@ def _speed_labels(bins, units):
     return labels
 
 
-def wind_rose(wind_rose: WindRose, title: str = 'Wind Rose', legend: bool = True,
-              colorset: ColorSet = ColorSet.original) -> Figure:
+def wind_rose(wind_rose: WindRose, title: str = None, show_title: bool = False) -> Figure:
     """Create a windrose plot.
 
     Args:
         wind_rose: A ladybug WindRose object.
-        title: A title for the plot. Defaults to Wind Rose.
-        legend: A boolean to show/hide legend. Defaults to True.
-        colorset: A ladybug colorset object. Defaults to ColorSet.original.
+        title: A title for the plot. Defaults to None.
+        show_title: A boolean to show or hide the title. Defaults to False.
 
     Returns:
         A plotly figure.
@@ -616,7 +652,7 @@ def wind_rose(wind_rose: WindRose, title: str = 'Wind Rose', legend: bool = True
     else:
         df = df.loc[(df["hour"] <= end_hour) | (df["hour"] >= start_hour)]
 
-    spd_colors = [rgb_to_hex(color) for color in color_set[colorset.value]]
+    spd_colors = [rgb_to_hex(color) for color in wind_rose.legend_parameters.colors]
     spd_bins = [-1, 0.5, 1.5, 3.3, 5.5, 7.9, 10.7, 13.8, 17.1, 20.7, np.inf]
     spd_labels = _speed_labels(spd_bins, units="m/s")
     dir_bins = np.arange(-22.5 / 2, 370, 22.5)
@@ -679,18 +715,30 @@ def wind_rose(wind_rose: WindRose, title: str = 'Wind Rose', legend: bool = True
             "N-N-W",
         ]
     )
-    if title != "":
-        fig.update_layout(title=title, title_x=0.5)
+
+    # setting the title for the figure
+    if show_title:
+        fig_title = {
+            'text': title if title else 'Wind Rose',
+            'y': 1,
+            'x': 0.5,
+            'xanchor': 'center',
+            'yanchor': 'top'
+        }
+    else:
+        if title:
+            raise ValueError(
+                f'Title is set to "{title}" but show_title is set to False.')
+        fig_title = None
+
     fig.update_layout(
         autosize=True,
         polar_angularaxis_rotation=90,
         polar_angularaxis_direction="clockwise",
-        showlegend=legend,
         dragmode=False,
         margin=dict(l=20, r=20, t=55, b=20),
+        title=fig_title,
     )
-    fig.update_xaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
-    fig.update_yaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
 
     return fig
 
@@ -730,20 +778,21 @@ def psych_chart(psych: PsychrometricChart, data: BaseCollection = None,
 
 
 def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
-            colorset: ColorSet = ColorSet.original, min_range: float = None,
-            max_range: float = None, title: str = None) -> Figure:
+            colorset: Colorset = Colorset.original(), min_range: float = None,
+            max_range: float = None, title: str = None, show_title: bool = False) -> Figure:
     """ Plot Sunpath.
 
     Args:
         sunpath: A Ladybug Sunpath object.
         data: An HourlyContinuousCollection object to be plotted on the sunpath. Defaults
             to None.
-        colorset: A ColorSet to be used for plotting. Defaults to ColorSet.original.
+        colorset: A Ladybug Colorset object. Defaults to ColorSet.original.
         min_range: Minimum value for the colorbar. If not set, the minimum value will be
             set to the minimum value of the data. Defaults to None.
         max_range: Maximum value for the colorbar. If not set, the maximum value will be
             set to the maximum value of the data. Defaults to None.
         title: A string to be used as the title of the plot. Defaults to None.
+        show_title: A boolean to show or hide the title of the plot. Defaults to False.
 
     Returns:
         A plotly Figure.
@@ -766,8 +815,8 @@ def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
 
         var_name = data.header.data_type.name
         var_unit = data.header.unit
-        var_colorscale = [rgb_to_hex(color) for color in color_set[colorset.value]]
-        title = 'Sunpath - ' + var_name if title is None else title
+        var_colorscale = [rgb_to_hex(color) for color in colorset]
+        chart_title = 'Sunpath - ' + var_name if title is None else title
 
         # add data to the dataframe
         df[var_name] = Series(data).values
@@ -788,7 +837,7 @@ def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
 
     else:
         solpos = df.loc[df["altitude"] > 0, :]
-        title = 'Sunpath' if title is None else title
+        chart_title = 'Sunpath' if title is None else title
 
     tz = "UTC"
     times = pd.date_range(
@@ -986,6 +1035,21 @@ def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
             )
         )
 
+    # setting the title for the figure
+    if show_title:
+        fig_title = {
+            'text': chart_title,
+            'y': 1,
+            'x': 0.5,
+            'xanchor': 'center',
+            'yanchor': 'top'
+        }
+    else:
+        if title:
+            raise ValueError(
+                f'Title is set to "{title}" but show_title is set to False.')
+        fig_title = None
+
     fig.update_layout(
         showlegend=False,
         polar=dict(
@@ -1001,13 +1065,7 @@ def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
         title_x=0.5,
         dragmode=False,
         margin=dict(l=20, r=20, t=33, b=20),
-        title={
-            'text': title,
-            'y': 1,
-            'x': 0.5,
-            'xanchor': 'center',
-            'yanchor': 'top'
-        }
+        title=fig_title,
     )
 
     return fig
